@@ -7,9 +7,4 @@ Puppet::Type.type(:neutron_agent_macvtap).provide(
     '/etc/neutron/plugins/ml2/macvtap_agent.ini'
   end
 
-  # added for backwards compatibility with older versions of inifile
-  def file_path
-    self.class.file_path
-  end
-
 end
