@@ -7,9 +7,4 @@ Puppet::Type.type(:neutron_l2gw_service_config).provide(
     '/etc/neutron/l2gw_plugin.ini'
   end
 
-  # added for backwards compatibility with older versions of inifile
-  def file_path
-    self.class.file_path
-  end
-
 end
