@@ -7,9 +7,4 @@ Puppet::Type.type(:neutron_metering_agent_config).provide(
     '/etc/neutron/metering_agent.ini'
   end
 
-  # added for backwards compatibility with older versions of inifile
-  def file_path
-    self.class.file_path
-  end
-
 end
