@@ -158,7 +158,7 @@ describe 'neutron::agents::ml2::linuxbridge' do
       end
 
       let (:platform_params) do
-        case facts[:osfamily]
+        case facts[:os]['family']
         when 'Debian'
           {
             :linuxbridge_agent_package => 'neutron-linuxbridge-agent',
