@@ -28,6 +28,16 @@ describe 'neutron::cache' do
           :memcache_pool_maxsize                => '<SERVICE DEFAULT>',
           :memcache_pool_unused_timeout         => '<SERVICE DEFAULT>',
           :memcache_pool_connection_get_timeout => '<SERVICE DEFAULT>',
+          :memcache_pool_flush_on_reconnect     => '<SERVICE DEFAULT>',
+          :memcache_sasl_enabled                => '<SERVICE DEFAULT>',
+          :memcache_username                    => '<SERVICE DEFAULT>',
+          :memcache_password                    => '<SERVICE DEFAULT>',
+          :redis_server                         => '<SERVICE DEFAULT>',
+          :redis_username                       => '<SERVICE DEFAULT>',
+          :redis_password                       => '<SERVICE DEFAULT>',
+          :redis_sentinels                      => '<SERVICE DEFAULT>',
+          :redis_socket_timeout                 => '<SERVICE DEFAULT>',
+          :redis_sentinel_service_name          => '<SERVICE DEFAULT>',
           :tls_enabled                          => '<SERVICE DEFAULT>',
           :tls_cafile                           => '<SERVICE DEFAULT>',
           :tls_certfile                         => '<SERVICE DEFAULT>',
@@ -63,6 +73,16 @@ describe 'neutron::cache' do
           :memcache_pool_maxsize                => '10',
           :memcache_pool_unused_timeout         => '120',
           :memcache_pool_connection_get_timeout => '360',
+          :memcache_pool_flush_on_reconnect     => false,
+          :memcache_sasl_enabled                => false,
+          :memcache_username                    => 'sasluser',
+          :memcache_password                    => 'saslpass',
+          :redis_server                         => 'localhost:6379',
+          :redis_username                       => 'redisuser',
+          :redis_password                       => 'redispass',
+          :redis_sentinels                      => ['host1:26379', 'host2:26379'],
+          :redis_socket_timeout                 => 1.0,
+          :redis_sentinel_service_name          => 'mymaster',
           :tls_enabled                          => false,
           :enable_retry_client                  => false,
           :retry_attempts                       => 2,
@@ -93,6 +113,16 @@ describe 'neutron::cache' do
           :memcache_pool_maxsize                => '10',
           :memcache_pool_unused_timeout         => '120',
           :memcache_pool_connection_get_timeout => '360',
+          :memcache_pool_flush_on_reconnect     => false,
+          :memcache_sasl_enabled                => false,
+          :memcache_username                    => 'sasluser',
+          :memcache_password                    => 'saslpass',
+          :redis_server                         => 'localhost:6379',
+          :redis_username                       => 'redisuser',
+          :redis_password                       => 'redispass',
+          :redis_sentinels                      => ['host1:26379', 'host2:26379'],
+          :redis_socket_timeout                 => 1.0,
+          :redis_sentinel_service_name          => 'mymaster',
           :tls_enabled                          => false,
           :tls_cafile                           => '<SERVICE DEFAULT>',
           :tls_certfile                         => '<SERVICE DEFAULT>',
