@@ -34,8 +34,9 @@ describe 'neutron::db::postgresql' do
     context "on #{os}" do
       let (:facts) do
         facts.merge(OSDefaults.get_facts({
-          :processorcount => 8,
-          :concat_basedir => '/var/lib/puppet/concat'
+          # puppet-postgresql requires the service_provider fact provided by
+          # puppetlabs-postgresql.
+          :service_provider => 'systemd'
         }))
       end
 
