@@ -13,25 +13,9 @@ describe 'neutron' do
   shared_examples 'neutron' do
     it_behaves_like 'a neutron base installation'
 
-    context 'with rabbitmq heartbeat configured' do
-      before { params.merge!( 
-        :rabbit_heartbeat_timeout_threshold => '60',
-        :rabbit_heartbeat_rate => '10',
-        :rabbit_heartbeat_in_pthread => true,
-      ) }
-      it_behaves_like 'rabbit with heartbeat configured'
-    end
-
-    context 'with rabbitmq durable queues configured' do
-      before { params.merge!( :amqp_durable_queues => true ) }
-      it_behaves_like 'rabbit with durable queues'
-    end
-
-    context 'with rabbitmq non default transient_queues_ttl' do
-      before { params.merge!( :rabbit_transient_queues_ttl => 20 ) }
-      it_behaves_like 'rabbit with non default transient_queues_ttl'
-    end
-
+    it_behaves_like 'with rabbit parameters configured'
+    it_behaves_like 'with notification parameters configured'
+    it_behaves_like 'with SSL enabled without kombu'
     it_behaves_like 'with SSL enabled with kombu'
     it_behaves_like 'with SSL enabled without kombu'
     it_behaves_like 'with SSL disabled'
@@ -48,10 +32,6 @@ describe 'neutron' do
     it_behaves_like 'with max_allowed_address_pair defined'
     it_behaves_like 'when disabling vlan_transparent'
     it_behaves_like 'when enabling vlan_transparent'
-
-    context 'with amqp messaging' do
-      it_behaves_like 'amqp support'
-    end
   end
 
   shared_examples 'a neutron base installation' do
@@ -76,6 +56,7 @@ describe 'neutron' do
         :transport_url => '<SERVICE DEFAULT>',
         :driver        => '<SERVICE DEFAULT>',
         :topics        => '<SERVICE DEFAULT>',
+        :retry         => '<SERVICE DEFAULT>',
       )
     end
 
@@ -84,6 +65,7 @@ describe 'neutron' do
         :heartbeat_timeout_threshold          => '<SERVICE DEFAULT>',
         :heartbeat_rate                       => '<SERVICE DEFAULT>',
         :heartbeat_in_pthread                 => '<SERVICE DEFAULT>',
+        :rabbit_qos_prefetch_count            => '<SERVICE DEFAULT>',
         :rabbit_use_ssl                       => '<SERVICE DEFAULT>',
         :rabbit_transient_queues_ttl          => '<SERVICE DEFAULT>',
         :kombu_reconnect_delay                => '<SERVICE DEFAULT>',
@@ -97,6 +79,7 @@ describe 'neutron' do
         :rabbit_quorum_delivery_limit         => '<SERVICE DEFAULT>',
         :rabbit_quorum_max_memory_length      => '<SERVICE DEFAULT>',
         :rabbit_quorum_max_memory_bytes       => '<SERVICE DEFAULT>',
+        :enable_cancel_on_failover            => '<SERVICE DEFAULT>',
       )
     end
 
@@ -133,46 +116,46 @@ describe 'neutron' do
     end
   end
 
-  shared_examples 'rabbit with heartbeat configured' do
+  shared_examples 'with rabbit parameters configured' do
+    before do
+      params.merge!(
+        :rabbit_heartbeat_timeout_threshold => 60,
+        :rabbit_heartbeat_rate              => 10,
+        :rabbit_heartbeat_in_pthread        => true,
+        :amqp_durable_queues                => true,
+        :rabbit_ha_queues                   => true,
+        :rabbit_transient_queues_ttl        => 20,
+      )
+    end
+
     it 'in neutron.conf' do
       should contain_oslo__messaging__rabbit('neutron_config').with(
-        :heartbeat_timeout_threshold => '60',
-        :heartbeat_rate              => '10',
+        :heartbeat_timeout_threshold => 60,
+        :heartbeat_rate              => 10,
         :heartbeat_in_pthread        => true,
+        :amqp_durable_queues         => true,
+        :rabbit_ha_queues            => true,
+        :rabbit_transient_queues_ttl => 20,
       )
     end
   end
 
-  shared_examples 'rabbit with durable queues' do
-    it 'in neutron.conf' do
-      should contain_oslo__messaging__rabbit('neutron_config').with(
-        :amqp_durable_queues => true
+  shared_examples 'with notification parameters configured' do
+    before do
+      params.merge!(
+        :notification_transport_url => 'rabbit://rabbit_user:password@localhost:5673',
+        :notification_driver        => 'mesagingv2',
+        :notification_topics        => 'notifications',
+        :notification_retry         => 10,
       )
     end
-  end
 
-  shared_examples 'rabbit with non default transient_queues_ttl' do
-    it 'in neutron.conf' do
-      should contain_oslo__messaging__rabbit('neutron_config').with(
-        :rabbit_transient_queues_ttl => 20
-      )
-    end
-  end
-
-  shared_examples 'rabbit_ha_queues set to false' do
-    it 'in neutron.conf' do
-      should contain_oslo__messaging__rabbit('neutron_config').with(
-        :rabbit_ha_queues => true
-      )
-    end
-  end
-
-  shared_examples 'notification_driver and notification_topics' do
     it 'in neutron.conf' do
       should contain_oslo__messaging__notifications('neutron_config').with(
         :transport_url => params[:notification_transport_url],
         :driver        => params[:notification_driver],
         :topics        => params[:notification_topics],
+        :retry         => params[:notification_retry],
       )
     end
   end
@@ -424,58 +407,6 @@ describe 'neutron' do
     end
   end
 
-  shared_examples 'amqp support' do
-    context 'with default amqp parameters' do
-      it { should contain_oslo__messaging__amqp('neutron_config').with(
-        :server_request_prefix => '<SERVICE DEFAULT>',
-        :broadcast_prefix      => '<SERVICE DEFAULT>',
-        :group_request_prefix  => '<SERVICE DEFAULT>',
-        :container_name        => '<SERVICE DEFAULT>',
-        :idle_timeout          => '<SERVICE DEFAULT>',
-        :trace                 => '<SERVICE DEFAULT>',
-        :ssl_ca_file           => '<SERVICE DEFAULT>',
-        :ssl_cert_file         => '<SERVICE DEFAULT>',
-        :ssl_key_file          => '<SERVICE DEFAULT>',
-        :ssl_key_password      => '<SERVICE DEFAULT>',
-        :sasl_mechanisms       => '<SERVICE DEFAULT>',
-        :sasl_config_dir       => '<SERVICE DEFAULT>',
-        :sasl_config_name      => '<SERVICE DEFAULT>',
-        :username              => '<SERVICE DEFAULT>',
-        :password              => '<SERVICE DEFAULT>',
-      ) }
-    end
-
-    context 'with overridden amqp parameters' do
-      before { params.merge!(
-        :amqp_idle_timeout  => '60',
-        :amqp_trace         => true,
-        :amqp_ssl_ca_file   => '/path/to/ca.cert',
-        :amqp_ssl_cert_file => '/path/to/certfile',
-        :amqp_ssl_key_file  => '/path/to/key',
-        :amqp_username      => 'amqp_user',
-        :amqp_password      => 'password',
-      ) }
-
-      it { should contain_oslo__messaging__amqp('neutron_config').with(
-        :server_request_prefix => '<SERVICE DEFAULT>',
-        :broadcast_prefix      => '<SERVICE DEFAULT>',
-        :group_request_prefix  => '<SERVICE DEFAULT>',
-        :container_name        => '<SERVICE DEFAULT>',
-        :idle_timeout          => '60',
-        :trace                 => true,
-        :ssl_ca_file           => '/path/to/ca.cert',
-        :ssl_cert_file         => '/path/to/certfile',
-        :ssl_key_file          => '/path/to/key',
-        :ssl_key_password      => '<SERVICE DEFAULT>',
-        :sasl_mechanisms       => '<SERVICE DEFAULT>',
-        :sasl_config_dir       => '<SERVICE DEFAULT>',
-        :sasl_config_name      => '<SERVICE DEFAULT>',
-        :username              => 'amqp_user',
-        :password              => 'password',
-      ) }
-    end
-  end
-
   shared_examples 'with max_allowed_address_pair defined' do
     before do
       params.merge!(
