@@ -17,12 +17,15 @@ describe 'neutron::keystone::auth' do
         :configure_endpoint  => true,
         :service_name        => 'neutron',
         :service_type        => 'network',
-        :service_description => 'Neutron Networking Service',
+        :service_description => 'OpenStack Networking Service',
         :region              => 'RegionOne',
         :auth_name           => 'neutron',
         :password            => 'neutron_password',
         :email               => 'neutron@localhost',
         :tenant              => 'services',
+        :roles               => ['admin'],
+        :system_scope        => 'all',
+        :system_roles        => [],
         :public_url          => 'http://127.0.0.1:9696',
         :internal_url        => 'http://127.0.0.1:9696',
         :admin_url           => 'http://127.0.0.1:9696',
@@ -35,10 +38,13 @@ describe 'neutron::keystone::auth' do
           :auth_name           => 'alt_neutron',
           :email               => 'alt_neutron@alt_localhost',
           :tenant              => 'alt_service',
+          :roles               => ['admin', 'service'],
+          :system_scope        => 'alt_all',
+          :system_roles        => ['admin', 'member', 'reader'],
           :configure_endpoint  => false,
           :configure_user      => false,
           :configure_user_role => false,
-          :service_description => 'Alternative Neutron Networking Service',
+          :service_description => 'Alternative OpenStack Networking Service',
           :service_name        => 'alt_service',
           :service_type        => 'alt_network',
           :region              => 'RegionTwo',
@@ -53,12 +59,15 @@ describe 'neutron::keystone::auth' do
         :configure_endpoint  => false,
         :service_name        => 'alt_service',
         :service_type        => 'alt_network',
-        :service_description => 'Alternative Neutron Networking Service',
+        :service_description => 'Alternative OpenStack Networking Service',
         :region              => 'RegionTwo',
         :auth_name           => 'alt_neutron',
         :password            => 'neutron_password',
         :email               => 'alt_neutron@alt_localhost',
         :tenant              => 'alt_service',
+        :roles               => ['admin', 'service'],
+        :system_scope        => 'alt_all',
+        :system_roles        => ['admin', 'member', 'reader'],
         :public_url          => 'https://10.10.10.10:80',
         :internal_url        => 'http://10.10.10.11:81',
         :admin_url           => 'http://10.10.10.12:81',
