@@ -23,6 +23,7 @@ describe 'neutron::plugins::ml2::ovn' do
       :ovsdb_retry_max_interval             => '<SERVICE DEFAULT>',
       :ovsdb_probe_interval                 => '<SERVICE DEFAULT>',
       :neutron_sync_mode                    => '<SERVICE DEFAULT>',
+      :ovn_metadata_enabled                 => '<SERVICE DEFAULT>',
       :dvr_enabled                          => '<SERVICE DEFAULT>',
       :disable_ovn_dhcp_for_baremetal_ports => '<SERVICE DEFAULT>',
       :dns_servers                          => '<SERVICE DEFAULT>',
@@ -34,6 +35,8 @@ describe 'neutron::plugins::ml2::ovn' do
       :localnet_learn_fdb                   => '<SERVICE DEFAULT>',
       :fdb_age_threshold                    => '<SERVICE DEFAULT>',
       :mac_binding_age_threshold            => '<SERVICE DEFAULT>',
+      :broadcast_arps_to_all_routers        => '<SERVICE DEFAULT>',
+      :ovn_router_indirect_snat             => '<SERVICE DEFAULT>',
       :ignore_lsp_down                      => '<SERVICE DEFAULT>',
       :fdb_removal_limit                    => '<SERVICE DEFAULT>',
       :mac_binding_removal_limit            => '<SERVICE DEFAULT>',
@@ -67,6 +70,7 @@ describe 'neutron::plugins::ml2::ovn' do
         should contain_neutron_plugin_ml2('ovn/ovsdb_retry_max_interval').with_value(p[:ovsdb_retry_max_interval])
         should contain_neutron_plugin_ml2('ovn/ovsdb_probe_interval').with_value(p[:ovsdb_probe_interval])
         should contain_neutron_plugin_ml2('ovn/neutron_sync_mode').with_value(p[:neutron_sync_mode])
+        should contain_neutron_plugin_ml2('ovn/ovn_metadata_enabled').with_value(p[:ovn_metadata_enabled])
         should contain_neutron_plugin_ml2('ovn/enable_distributed_floating_ip').with_value(p[:dvr_enabled])
         should contain_neutron_plugin_ml2('ovn/disable_ovn_dhcp_for_baremetal_ports').with_value(p[:disable_ovn_dhcp_for_baremetal_ports])
         should contain_neutron_plugin_ml2('ovn/dns_servers').with_value(p[:dns_servers])
@@ -78,6 +82,8 @@ describe 'neutron::plugins::ml2::ovn' do
         should contain_neutron_plugin_ml2('ovn/localnet_learn_fdb').with_value(p[:localnet_learn_fdb])
         should contain_neutron_plugin_ml2('ovn/fdb_age_threshold').with_value(p[:fdb_age_threshold])
         should contain_neutron_plugin_ml2('ovn/mac_binding_age_threshold').with_value(p[:mac_binding_age_threshold])
+        should contain_neutron_plugin_ml2('ovn/broadcast_arps_to_all_routers').with_value(p[:broadcast_arps_to_all_routers])
+        should contain_neutron_plugin_ml2('ovn/ovn_router_indirect_snat').with_value(p[:ovn_router_indirect_snat])
         should contain_neutron_plugin_ml2('ovn_nb_global/ignore_lsp_down').with_value(p[:ignore_lsp_down])
         should contain_neutron_plugin_ml2('ovn_nb_global/fdb_removal_limit').with_value(p[:fdb_removal_limit])
         should contain_neutron_plugin_ml2('ovn_nb_global/mac_binding_removal_limit').with_value(p[:mac_binding_removal_limit])
@@ -102,6 +108,7 @@ describe 'neutron::plugins::ml2::ovn' do
           :ovsdb_retry_max_interval             => 180,
           :ovsdb_probe_interval                 => 60000,
           :neutron_sync_mode                    => 'log',
+          :ovn_metadata_enabled                 => true,
           :dvr_enabled                          => false,
           :disable_ovn_dhcp_for_baremetal_ports => false,
           :dns_servers                          => '8.8.8.8,10.10.10.10',
@@ -113,6 +120,8 @@ describe 'neutron::plugins::ml2::ovn' do
           :localnet_learn_fdb                   => false,
           :fdb_age_threshold                    => 10,
           :mac_binding_age_threshold            => 11,
+          :broadcast_arps_to_all_routers        => true,
+          :ovn_router_indirect_snat             => false,
           :ignore_lsp_down                      => false,
           :fdb_removal_limit                    => 12,
           :mac_binding_removal_limit            => 13,
@@ -132,6 +141,7 @@ describe 'neutron::plugins::ml2::ovn' do
         should contain_neutron_plugin_ml2('ovn/ovsdb_retry_max_interval').with_value(p[:ovsdb_retry_max_interval])
         should contain_neutron_plugin_ml2('ovn/ovsdb_probe_interval').with_value(p[:ovsdb_probe_interval])
         should contain_neutron_plugin_ml2('ovn/neutron_sync_mode').with_value(p[:neutron_sync_mode])
+        should contain_neutron_plugin_ml2('ovn/ovn_metadata_enabled').with_value(p[:ovn_metadata_enabled])
         should contain_neutron_plugin_ml2('ovn/enable_distributed_floating_ip').with_value(p[:dvr_enabled])
         should contain_neutron_plugin_ml2('ovn/disable_ovn_dhcp_for_baremetal_ports').with_value(p[:disable_ovn_dhcp_for_baremetal_ports])
         should contain_neutron_plugin_ml2('ovn/dns_servers').with_value(p[:dns_servers])
@@ -143,6 +153,8 @@ describe 'neutron::plugins::ml2::ovn' do
         should contain_neutron_plugin_ml2('ovn/localnet_learn_fdb').with_value(p[:localnet_learn_fdb])
         should contain_neutron_plugin_ml2('ovn/fdb_age_threshold').with_value(p[:fdb_age_threshold])
         should contain_neutron_plugin_ml2('ovn/mac_binding_age_threshold').with_value(p[:mac_binding_age_threshold])
+        should contain_neutron_plugin_ml2('ovn/broadcast_arps_to_all_routers').with_value(p[:broadcast_arps_to_all_routers])
+        should contain_neutron_plugin_ml2('ovn/ovn_router_indirect_snat').with_value(p[:ovn_router_indirect_snat])
         should contain_neutron_plugin_ml2('ovn_nb_global/ignore_lsp_down').with_value(p[:ignore_lsp_down])
         should contain_neutron_plugin_ml2('ovn_nb_global/fdb_removal_limit').with_value(p[:fdb_removal_limit])
         should contain_neutron_plugin_ml2('ovn_nb_global/mac_binding_removal_limit').with_value(p[:mac_binding_removal_limit])
