@@ -273,7 +273,6 @@ describe 'neutron::server' do
         params.merge!(
           :service_name     => false,
           :api_service_name => 'httpd',
-          :rpc_service_name => 'neutron-rpc-server',
         )
       end
 
@@ -302,12 +301,36 @@ describe 'neutron::server' do
           )
         end
 
-        should contain_service('neutron-rpc-server').with(
-          :ensure => 'running',
-          :name   => 'neutron-rpc-server',
-          :enable => true,
-          :tag    => ['neutron-service'],
-        )
+        if platform_params.has_key?(:rpc_package_name)
+          should contain_package('neutron-rpc-server').with(
+            :name   => platform_params[:rpc_package_name],
+            :ensure => 'present',
+            :tag    => ['openstack', 'neutron-package'],
+          )
+        end
+        if platform_params.has_key?(:rpc_service_name)
+          should contain_service('neutron-rpc-server').with(
+            :ensure => 'running',
+            :name   => platform_params[:rpc_service_name],
+            :enable => true,
+            :tag    => ['neutron-service'],
+          )
+        end
+        if platform_params.has_key?(:periodic_workers_package_name)
+          should contain_package('neutron-periodic-workers').with(
+            :name   => platform_params[:periodic_workers_package_name],
+            :ensure => 'present',
+            :tag    => ['openstack', 'neutron-package'],
+          )
+        end
+        if platform_params.has_key?(:periodic_workers_service_name)
+          should contain_service('neutron-periodic-workers').with(
+            :ensure => 'running',
+            :name   => platform_params[:periodic_workers_service_name],
+            :enable => true,
+            :tag    => ['neutron-service'],
+          )
+        end
       end
     end
 
@@ -374,22 +397,6 @@ describe 'neutron::server' do
       end
     end
 
-    context 'with VPNaaS package installation' do
-      before do
-        params.merge!(
-          :ensure_vpnaas_package => true,
-        )
-      end
-
-      it 'should install VPNaaS package' do
-        should contain_package('neutron-vpnaas-agent').with(
-          :ensure => 'installed',
-          :name   => platform_params[:vpnaas_agent_package],
-          :tag    => ['openstack', 'neutron-package'],
-        )
-      end
-    end
-
     context 'with Dynamic routing package installation' do
       before do
         params.merge!( :ensure_dr_package => true )
@@ -432,13 +439,13 @@ describe 'neutron::server' do
             {
               :server_package          => 'neutron-server',
               :server_service          => 'neutron-server',
-              :rpc_service_name        => 'neutron-rpc-server',
               :dynamic_routing_package => 'python3-neutron-dynamic-routing',
               :vpnaas_agent_package    => 'python3-neutron-vpnaas',
             }
           else
             {
               :api_service_name        => 'neutron-api',
+              :rpc_package_name        => 'neutron-rpc-server',
               :rpc_service_name        => 'neutron-rpc-server',
               :dynamic_routing_package => 'python3-neutron-dynamic-routing',
               :vpnaas_agent_package    => 'python3-neutron-vpnaas',
@@ -446,10 +453,13 @@ describe 'neutron::server' do
           end
         when 'RedHat'
           {
-            :server_service          => 'neutron-server',
-            :rpc_service_name        => 'neutron-rpc-server',
-            :dynamic_routing_package => 'python3-neutron-dynamic-routing',
-            :vpnaas_agent_package    => 'openstack-neutron-vpnaas',
+            :server_service                => 'neutron-server',
+            :rpc_package_name              => 'openstack-neutron-rpc-server',
+            :rpc_service_name              => 'neutron-rpc-server',
+            :periodic_workers_package_name => 'openstack-neutron-periodic-workers',
+            :periodic_workers_service_name => 'neutron-periodic-workers',
+            :dynamic_routing_package       => 'python3-neutron-dynamic-routing',
+            :vpnaas_agent_package          => 'openstack-neutron-vpnaas',
           }
         end
       end
