@@ -32,12 +32,13 @@ describe 'neutron::services::l2gw' do
       end
 
       it 'configures l2gw_plugin.ini' do
-        should contain_neutron_l2gw_service_config('service_providers/service_provider').with_value('<SERVICE DEFAULT>')
         should contain_neutron_l2gw_service_config('DEFAULT/default_interface_name').with_value('<SERVICE DEFAULT>')
         should contain_neutron_l2gw_service_config('DEFAULT/default_device_name').with_value('<SERVICE DEFAULT>')
         should contain_neutron_l2gw_service_config('DEFAULT/quota_l2_gateway').with_value('<SERVICE DEFAULT>')
         should contain_neutron_l2gw_service_config('DEFAULT/periodic_monitoring_interval').with_value('<SERVICE DEFAULT>')
-        should contain_neutron_l2gw_service_config('service_providers/service_provider').with_value('<SERVICE DEFAULT>')
+        should contain_neutron_l2gw_service_config('service_providers/service_provider').with_value(
+          'L2GW:l2gw:networking_l2gw.services.l2gateway.service_drivers.rpc_l2gw.L2gwRpcDriver:default'
+        )
       end
 
       it 'does not run neutron-db-manage' do
@@ -73,7 +74,7 @@ describe 'neutron::services::l2gw' do
 
       it 'runs neutron-db-manage' do
         should contain_exec('l2gw-db-sync').with(
-          :command     => 'neutron-db-manage --config-file /etc/neutron/neutron.conf --subproject networking-l2gw upgrade head',
+          :command     => 'neutron-db-manage --subproject networking-l2gw upgrade head',
           :path        => '/usr/bin',
           :user        => 'neutron',
           :subscribe   => ['Anchor[neutron::install::end]',
