@@ -9,12 +9,12 @@ describe 'Puppet::Type.type(:neutron_bgpvpn_bagpipe_config)' do
 
   it 'should autorequire the package that install the file' do
     catalog = Puppet::Resource::Catalog.new
-    package = Puppet::Type.type(:package).new(:name => 'openstack-bagpipe-bgp')
-    catalog.add_resource package, @neutron_bgpvpn_bagpipe_config
+    anchor = Puppet::Type.type(:anchor).new(:name => 'neutron::install::end')
+    catalog.add_resource anchor, @neutron_bgpvpn_bagpipe_config
     dependency = @neutron_bgpvpn_bagpipe_config.autorequire
     expect(dependency.size).to eq(1)
     expect(dependency[0].target).to eq(@neutron_bgpvpn_bagpipe_config)
-    expect(dependency[0].source).to eq(package)
+    expect(dependency[0].source).to eq(anchor)
   end
 
 end
